==> nwchem_7.0.1.orig.tar.gz: nwchem-7.0.1-release/README.md <==
 



[![Build Travis-CI Status](https://img.shields.io/travis/nwchemgit/nwchem.svg)](https://travis-ci.org/nwchemgit/nwchem/builds)
[![License](https://img.shields.io/badge/license-ECL2-blue.svg)](https://raw.githubusercontent.com/nwchemgit/nwchem/master/LICENSE.md)
[![Github Downloads All Releases](https://img.shields.io/github/downloads/nwchemgit/nwchem/total.svg)](https://github.com/nwchemgit/nwchem/releases)
[![Github Downloads Release 6.8](https://img.shields.io/github/downloads/nwchemgit/nwchem/v6.8-release/total.svg)](https://github.com/nwchemgit/nwchem/releases/tag/v6.8-release)
[![Github Downloads Release 6.8.1](https://img.shields.io/github/downloads/nwchemgit/nwchem/6.8.1-release/total.svg)](https://github.com/nwchemgit/nwchem/releases/tag/6.8.1-release)
[![Github Downloads Release 7.0.0](https://img.shields.io/github/downloads/nwchemgit/nwchem/v7.0.0-release/total.svg)](https://github.com/nwchemgit/nwchem/releases/tag/v7.0.0-release)

[![All Releases tags](https://img.shields.io/github/release/nwchemgit/nwchem/all.svg)](https://github.com/nwchemgit/nwchem/releases)  
[![EMSL](https://rawgit.com/nwchemgit/nwchem/master/contrib/git.nwchem/emsl_logo2.svg)](https://www.emsl.pnl.gov)
 
## NWChem: Open Source High-Performance Computational Chemistry
<img alt="NWChem logo" src="https://raw.githubusercontent.com/nwchemgit/nwchem/master/contrib/git.nwchem/MS3_logo_cropped.png" align=middle width="102pt" height="117pt"/>  
NWChem is actively developed by a consortium of developers and maintained by the Environmental Molecular Sciences Laboratory (EMSL), a US DOE Office of Science User Facility
located at the Pacific Northwest National Laboratory (PNNL) in Washington State

### Scalable computational chemistry tools

Source download instructions

* Master
```
git clone https://github.com/nwchemgit/nwchem.git

* 7.0.0 Release

git clone  -b release-7-0-0 https://github.com/nwchemgit/nwchem.git nwchem-7.0.0

### Release 7.0.0

Release files available at the page  
https://github.com/nwchemgit/nwchem/releases/tag/7.0.0-release   
Tar files for download:  
https://github.com/nwchemgit/nwchem/releases/download/v7.0.0-release/nwchem-7.0.0-release.revision-2c9a1c7c-srconly.2020-02-26.tar.bz2  
https://github.com/nwchemgit/nwchem/releases/download/v7.0.0-release/nwchem-7.0.0-release.revision-2c9a1c7c-nonsrconly.2020-02-26.tar.bz2  
Release notes available at  
https://github.com/nwchemgit/nwchem/raw/hotfix/release-7-0-0/release.notes.7.0.0

### Documentation
https://github.com/nwchemgit/nwchem/wiki

==> nwchem_7.0.2.orig.tar.gz: nwchem-7.0.2-release/README.md <==
 



[![Build Travis-CI Status](https://img.shields.io/travis/nwchemgit/nwchem.svg)](https://travis-ci.org/nwchemgit/nwchem/builds)
[![License](https://img.shields.io/badge/license-ECL2-blue.svg)](https://raw.githubusercontent.com/nwchemgit/nwchem/master/LICENSE.md)
[![Github Downloads All Releases](https://img.shields.io/github/downloads/nwchemgit/nwchem/total.svg)](https://github.com/nwchemgit/nwchem/releases)
[![Github Downloads Release 6.8](https://img.shields.io/github/downloads/nwchemgit/nwchem/v6.8-release/total.svg)](https://github.com/nwchemgit/nwchem/releases/tag/v6.8-release)
[![Github Downloads Release 6.8.1](https://img.shields.io/github/downloads/nwchemgit/nwchem/6.8.1-release/total.svg)](https://github.com/nwchemgit/nwchem/releases/tag/6.8.1-release)
[![Github Downloads Release 7.0.0](https://img.shields.io/github/downloads/nwchemgit/nwchem/v7.0.0-release/total.svg)](https://github.com/nwchemgit/nwchem/releases/tag/v7.0.0-release)
[![Github Downloads Release 7.0.1](https://img.shields.io/github/downloads/nwchemgit/nwchem/v7.0.1-release/total.svg)](https://github.com/nwchemgit/nwchem/releases/tag/v7.0.1-release)


[![All Releases tags](https://img.shields.io/github/release/nwchemgit/nwchem/all.svg)](https://github.com/nwchemgit/nwchem/releases)  
[![EMSL](https://rawgit.com/nwchemgit/nwchem/master/contrib/git.nwchem/emsl_logo2.svg)](https://www.emsl.pnl.gov)
 
## NWChem: Open Source High-Performance Computational Chemistry
<img alt="NWChem logo" src="https://raw.githubusercontent.com/nwchemgit/nwchem/master/contrib/git.nwchem/MS3_logo_cropped.png" align=middle width="102pt" height="117pt"/>  
NWChem is actively developed by a consortium of developers and maintained by the Environmental Molecular Sciences Laboratory (EMSL), a US DOE Office of Science User Facility
located at the Pacific Northwest National Laboratory (PNNL) in Washington State

### Scalable computational chemistry tools

Source download instructions

* Master

git clone https://github.com/nwchemgit/nwchem.git

* 7.0.1 Release

git clone  -b hotfix/release-7-0-0 https://github.com/nwchemgit/nwchem.git nwchem-7.0.1

### Release 7.0.1

Release files available at the page  
https://github.com/nwchemgit/nwchem/releases/tag/v7.0.1-release  
Tar files for download:  
https://github.com/nwchemgit/nwchem/releases/download/v7.0.1-release/nwchem-7.0.1-release.revision-9d9840c2-srconly.2020-10-08.tar.bz2  
https://github.com/nwchemgit/nwchem/releases/download/v7.0.1-release/nwchem-7.0.1-release.revision-9d9840c2-nonsrconly.2020-10-08.tar.bz2  
Release notes available at  
https://raw.githubusercontent.com/nwchemgit/nwchem/v7.0.1-release/release.notes.7.0.1

### Documentation
https://nwchemgit.github.io
